@@ -174,8 +174,12 @@ class SessionElement(DrissionElement):
         - 用loc元组查找：                                                                                 \n
             ele.ele((By.CLASS_NAME, 'ele_class')) - 返回第一个class为ele_class的子元素                     \n
         - 用查询字符串查找：                                                                               \n
-            查找方式：属性、tag name和属性、文本、xpath、css selector                                        \n
-            其中，@表示属性，=表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串                         \n
+            查找方式：属性、tag name和属性、文本、xpath、css selector、id、class                             \n
+            @表示属性，.表示class，#表示id，=表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串           \n
+            ele.ele('.ele_class')                       - 返回第一个 class 为 ele_class 的子元素            \n
+            ele.ele('.:ele_class')                      - 返回第一个 class 中含有 ele_class 的子元素         \n
+            ele.ele('#ele_id')                          - 返回第一个 id 为 ele_id 的子元素                  \n
+            ele.ele('#:ele_id')                         - 返回第一个 id 中含有 ele_id 的子元素               \n
             ele.ele('@class:ele_class')                 - 返回第一个class含有ele_class的子元素              \n
             ele.ele('@name=ele_name')                   - 返回第一个name等于ele_name的子元素                \n
             ele.ele('@placeholder')                     - 返回第一个带placeholder属性的子元素               \n
@@ -224,8 +228,12 @@ class SessionElement(DrissionElement):
         - 用loc元组查找：                                                                                \n
             ele.eles((By.CLASS_NAME, 'ele_class')) - 返回所有class为ele_class的子元素                     \n
         - 用查询字符串查找：                                                                              \n
-            查找方式：属性、tag name和属性、文本、xpath、css selector                                       \n
-            其中，@表示属性，=表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串                        \n
+            查找方式：属性、tag name和属性、文本、xpath、css selector、id、class                             \n
+            @表示属性，.表示class，#表示id，=表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串           \n
+            ele.eles('.ele_class')                       - 返回所有 class 为 ele_class 的子元素            \n
+            ele.eles('.:ele_class')                      - 返回所有 class 中含有 ele_class 的子元素         \n
+            ele.eles('#ele_id')                          - 返回所有 id 为 ele_id 的子元素                  \n
+            ele.eles('#:ele_id')                         - 返回所有 id 中含有 ele_id 的子元素               \n
             ele.eles('@class:ele_class')                 - 返回所有class含有ele_class的子元素              \n
             ele.eles('@name=ele_name')                   - 返回所有name等于ele_name的子元素                \n
             ele.eles('@placeholder')                     - 返回所有带placeholder属性的子元素               \n
